==> linstor-server-1.18.1-rc.1.tar.gz: linstor-server-1.18.1-rc.1/server/src/main/java/com/linbit/linstor/storage/interfaces/layers/drbd/DrbdRscDfnObject.java <==
package com.linbit.linstor.storage.interfaces.layers.drbd;

import com.linbit.linstor.core.types.TcpPortNumber;
import com.linbit.linstor.dbdrivers.DatabaseException;
import com.linbit.linstor.storage.interfaces.categories.resource.RscDfnLayerObject;

public interface DrbdRscDfnObject extends RscDfnLayerObject
{
    TcpPortNumber getTcpPort();

    TransportType getTransportType();

    String getSecret();

    short getPeerSlots();

    int getAlStripes();

    long getAlStripeSize();

    boolean isDown();

    void setDown(boolean downRef) throws DatabaseException;

    enum TransportType
    {
        IP, RDMA, RoCE;

        public static TransportType byValue(String str)
        {
            TransportType type = null;
            switch (str.toUpperCase())
            {
                case "IP":
                    type = IP;
                    break;
                case "RDMA":
                    type = RDMA;
                    break;
                case "ROCE":
                    type = RoCE;
                    break;
                default:
                    throw new IllegalArgumentException(
                        "Unknown TransportType: '" + str + "'"
                    );
            }
            return type;
        }

        public static TransportType valueOfIgnoreCase(String string, TransportType defaultValue)
            throws IllegalArgumentException
        {
            TransportType ret = defaultValue;
            if (string != null)
            {
                TransportType val = valueOf(string.toUpperCase());
                if (val != null)
                {
                    ret = val;
                }
            }
            return ret;
        }
    }
}

==> linstor-server-1.24.0-rc.1.tar.gz: linstor-server-1.24.0-rc.1/server/src/main/java/com/linbit/linstor/storage/interfaces/layers/drbd/DrbdRscDfnObject.java <==
package com.linbit.linstor.storage.interfaces.layers.drbd;

import com.linbit.linstor.core.types.TcpPortNumber;
import com.linbit.linstor.dbdrivers.DatabaseException;
import com.linbit.linstor.storage.interfaces.categories.resource.RscDfnLayerObject;

public interface DrbdRscDfnObject extends RscDfnLayerObject
{
    TcpPortNumber getTcpPort();

    TransportType getTransportType();

    String getSecret();

    short getPeerSlots();

    int getAlStripes();

    long getAlStripeSize();

    boolean isDown();

    void setDown(boolean downRef) throws DatabaseException;

    enum TransportType
    {
        IP, RDMA, RoCE;

        public static TransportType byValue(String str) throws IllegalArgumentException
        {
            TransportType type = null;
            switch (str.toUpperCase())
            {
                case "IP":
                    type = IP;
                    break;
                case "RDMA":
                    type = RDMA;
                    break;
                case "ROCE":
                    type = RoCE;
                    break;
                default:
                    throw new IllegalArgumentException(
                        "Unknown TransportType: '" + str + "'"
                    );
            }
            return type;
        }

        public static TransportType valueOfIgnoreCase(String string, TransportType defaultValue)
            throws IllegalArgumentException
        {
            TransportType ret = defaultValue;
            if (string != null)
            {
                TransportType val = valueOf(string.toUpperCase());
                if (val != null)
                {
                    ret = val;
                }
            }
            return ret;
        }
    }
}
